MultiNodeClone

Struct MultiNodeClone 

pub struct MultiNodeClone { /* private fields */ }
Clone all nodes in cluster definition asynchronously.

Implementations

Source

impl MultiNodeClone

pub fn new(cluster: &Cluster, jobs: Option<usize>) -> Result<Self>

Construct new multi-node clone type from cluster definition.

Extracts all node entries from cluster definition. Will set the number of threads/jobs that will be used during the cloning of all nodes, with None resulting the saturation of all CPU cores as much as possible.

Errors
  • Will fail if repository entry could not be constructed for a given node entry.
pub async fn clone_all(self) -> Result<()>

Clone all node entries in cluster asynchronously.

Shows clone progress for each clone tasks. Tasks may block if user needs to enter their credentials.

Invariants
  • Progress bars are properly finished no matter what.
Panics
  • Will panic if mutex guard fails to lock.
  • Will panic if mutex cannot be unwrapped to extract clone task result data.
Errors
  • Will fail for clone task failure.
    • Failed clone tasks will not cancel any active clone tasks that are not failing.
    • Results are only collected until all clone tasks have finished.
    • All errors are reported in one-shot.